.. _bases_charm:

Charm with the ``bases`` keyword
********************************

.. currentmodule:: charmcraft.models.project

.. autopydantic_model:: BasesCharm
    :model-show-config-summary: False
    :model-show-field-summary: False
    :model-show-validator-summary: False
    :model-show-validator-members: False
    :model-summary-list-order: bysource
    :member-order: bysource
    :field-list-validators: False
    :exclude-members: base, version, license, contact, issues, source-code

.. autopydantic_model:: BasesConfiguration
    :model-show-config-summary: False
    :model-show-field-summary: False
    :model-show-validator-summary: False
    :model-show-validator-members: False
    :model-summary-list-order: bysource
    :member-order: bysource
    :field-list-validators: False

.. autopydantic_model:: charmcraft.models.charmcraft.Base
    :model-show-config-summary: False
    :model-show-field-summary: False
    :model-show-validator-summary: False
    :model-show-validator-members: False
    :model-summary-list-order: bysource
    :member-order: bysource
    :field-list-validators: False

.. autopydantic_model:: Links
    :model-show-config-summary: False
    :model-show-field-summary: False
    :model-show-validator-summary: False
    :model-show-validator-members: False
    :model-summary-list-order: bysource
    :member-order: bysource
    :field-list-validators: False
